!     Last change:  ZK   25 Sep 2018   12:32 pm
!.. Last change:  ZK    5 Jan 2010   12:07 pm
      PROGRAM SURFACE_OKADA
! ( zo, zn, H, dx, dy, csz,    &
!                                lonL, latB, dlon, dlat,    &
!                                 js, je, ks, ke, nsmooth )

!---------------------------------------------------------------------
!
!  This program sets up the initial codition of sea surface
!  deformation at t =0 sec using the Okada solution of for a rectangular
!  fault (1985) .
!
!   Z.Kowalik  2006  IMS, University of Alaska Fairbanks
!   Y.Yamazaki 2007  ORE, University of Hawaii Manoa
!---------------------------------------------------------------------
      include "ALL_INPUT_OKADA"
!      IMPLICIT NONE

!      INTEGER,PARAMETER:: nsmooth = 50       ! (-)

!  (INOUT)...
!      REAL, DIMENSION(js:je, ks:ke):: zo, zn

!  (IN)...
!      REAL, DIMENSION(js:je,ks:ke):: H

!      REAL, DIMENSION(ks:ke):: csz
!      REAL:: dx, dy
!      REAL:: dlon, dlat
!      REAL:: lonL, latB
!      INTEGER:: js, je, ks, ke
!      INTEGER:: nsmooth


!  (INTERNAL)...
      REAL :: Trise
      REAL(dp) :: D0
      REAL(dp) :: L, W
      REAL(dp) :: lonR, latR, dR
      REAL(dp) :: strike, dip, rake
      REAL :: xdisL, xdisR, ydisB, ydisT

      REAL(dp), DIMENSION(js:je, ks:ke) :: disx, disy, disz

      NAMELIST/ fault_paramter / Trise, D0,         &
                                 lonR, latR, dR,    &
                                 L, W,              &
                                 strike, dip, rake

      NAMELIST/ dis_area / xdisL, xdisR, ydisB, ydisT

      INTEGER :: j, k, i
      INTEGER :: jdisL, jdisR, kdisB, kdisT

      zo =0. ; zn = 0.;  H  =0.

! call bathymetry
      CALL INPUT_BATHYMETRY

!     Open input file fault1.data and read the corresponding data.

      OPEN( UNIT=61, FILE = 'fault_2009_USGS.txt' )
      READ( 61, NML  = fault_paramter )
      READ( 61, NML  = dis_area )
      CLOSE(61)

      PRINT *, ' - Fault 1 ------------------------------------------ '
      PRINT *, ' '
      PRINT *, '  rise time =',Trise,'(s)'
      PRINT *, ' '
      PRINT *, ' Reference Point'
      PRINT *, '             ',latR,'(deg N)'
      PRINT *, '             ',lonR,'(deg E)'
      PRINT *, ' Fault Dimension'
      PRINT *, '   L        =', L/1000.,  '(km)'
      PRINT *, '   W        =', W/1000.,   '(km)'
      PRINT *, ' '
      PRINT *, '  depth     =',dR/1000.,'(km)'
      PRINT *, ' '
      PRINT *, '  slip      =', D0,       '(m)'
      PRINT *, ' '
      PRINT *, '  strike    =', strike,'(deg)'
      PRINT *, '  dip       =', dip,   '(deg)'
      PRINT *, '  rake      =', rake,  '(deg)'
      PRINT *, ' '
      PRINT *, ' ----------------------------------------------------- '

      strike = strike*rad  !phi    (rad):strike angle
      dip    = dip*rad     !delta  (rad):dip angle
      rake   = rake*rad    !lambda (rad):rake angle

      CALL OKADA3D_REC( js, je, ks, ke,       &
                        dx, dy, csz,          &
                        lonL, latB,           &
                        lonR, latR, dR,       &
                        L, W, D0,             &
                        strike, dip,  rake,   &
                        disx,   disy, disz  )

!      WRITE (151) ( (disx(j,k) ,j=js,je ), k=ks,ke )
!      WRITE (152) ( (disy(j,k) ,j=js,je ), k=ks,ke )
!      WRITE (153) ( (disz(j,k) ,j=js,je ), k=ks,ke )

      jdisL  = (xdisL-lonL)/dlon+1   ! j at LEFT   edge of OKADA Deformation applied area
      jdisR  = (xdisR-lonL)/dlon+1   ! j at RIGHT  edge of OKADA Deformation applied area
      kdisB  = (ydisB-latB)/dlat+1   ! k at BOTTOM edge of OKADA Deformation applied area
      kdisT  = (ydisT-latB)/dlat+1   ! k at TOP    edge of OKADA Deformation applied area

      PRINT *, '  jdisL    =', jdisL
      PRINT *, '  jdisR    =', jdisR
      PRINT *, '  kdisB    =', kdisB
      PRINT *, '  kdisT    =', kdisT

!... input sea surface deformation within the area, (jdisL:jdisR,kdisB:kdisT)

!      disz = 200.0 ! for Boundary TEST
      DO k = kdisB,kdisT
        DO j= jdisL,jdisR
          IF (H(j,k) .GT. EPSILON ) THEN
            zo(j,k) = disz(j,k)
          END IF
        END DO
      END DO

!... smooth the "nsmooth" points from the boundaries of the sea surface
!    deformation applied area, (jdisL:jdisR,kdisB:kdisT)
      DO i =1, nsmooth
        k =kdisB-i
        DO j=jdisL-i,jdisR+i
          IF (H(j, k) .GT. EPSILON ) THEN
            zo(j, k)=FLOAT(nsmooth -i)/FLOAT(nsmooth)*disz(j, k)
          END IF
        END DO

        k =kdisT+i
        DO j=jdisL-i,jdisR+i
          IF (H(j, k) .GT. EPSILON ) THEN
            zo(j, k)=FLOAT(nsmooth -i)/FLOAT(nsmooth)*disz(j, k)
          END IF
        END DO

        j=jdisL-i
        DO k =kdisB-i+1,kdisT+i-1
          IF (H(j, k) .GT. EPSILON ) THEN
            zo(j, k)=FLOAT(nsmooth -i)/FLOAT(nsmooth)*disz(j, k)
          END IF
        END DO

        j=jdisR+i
        DO k =kdisB-i+1,kdisT+i-1
          IF (H(j,k) .GT. EPSILON ) THEN
            zo(j, k)=FLOAT(nsmooth -i)/FLOAT(nsmooth)*disz(j, k)
          END IF
        END DO
      END DO

      DO j=js,je
        DO k=ks,ke
!          IF ( zo(j,k) .GT. -2.5       &
          IF ( zo(j, k) .GT. -1.0 .AND. zo(j, k) .LT. EPSILON ) THEN
            zo(j, k)=EPSILON
          END IF
        END DO
      END DO

      zn=zo
      open(unit=18,file='bottom_disp.dat',status='unknown')
      DO K=1, KE
        write (18,*) (zn(J,K),J=1,JE)
      END DO

CONTAINS

      SUBROUTINE INPUT_BATHYMETRY()
  !------------------------------------------------------------------------
        !USE ALL_INPUT_VARIABLES_DEC
        IMPLICIT NONE

        INTEGER :: j, k

  !------------------------------------------------------------------------
  !.. H, water depth at zeta cal point
  !------------------------------------------------------------------------

  ! 1st Layer
  !------------------------------------------------------------------------

  ! (1). Binary format
  !      OPEN ( UNIT=11,                              &
  !             FILE='ale2min.dat',                   &
  !             FORM='unformatted',STATUS='unknown')
  !      READ(11) ( (H1(j,k), j = js1,je1 ),k = ks1,ke1 )

  ! (2). ASCI format
      OPEN ( UNIT=11, FILE='samoa_30sec_G_rec.dat', STATUS='OLD' )
  !             FILE='samoa_30sec_ori.dat',      &
            
      READ(11,*) ( (H(j,k), j = js,je ),k = ks,ke )

  !    WRITE (104) ( (H1(j,k), j=js1,je1 ) ,k=ks1,ke1 )  ! 'H.dat': NO cutoff topo

      DO j=js, je
        DO k=ks, ke
          H(j, k) = -H(j, k)*100.                !H(cm) NOTE: Wet +, Dry -
          IF( H(j, k) .LT. -5000. ) THEN
            H(j,k) = -5000.                      ! cut land higher than 50 m
          END IF                                 ! for bottom deformation case
        END DO
      END DO
      WRITE (104) ( (H(j,k), j=js,je ) ,k=ks,ke )! 'H.dat': cutoff topo
      END subroutine


      SUBROUTINE TRIGON()
!------------------------------------------------------------------------
! This subroutine calculates the parameters used in the spherical coordinate
! system calculation
!
!
!   Z.Kowalik  2006 IMS      University of Alaska Fairbanks
!   W.Knight   2007 NOAA/NWS National Tsunami Warning Center
!   Y.Yamazaki 2007 ORE      University of Hawaii Manoa
!------------------------------------------------------------------------
!USE ALL_INPUT_VARIABLES_DEC
      IMPLICIT NONE

  !  (IN)...
      REAL    :: dlat, latB
      INTEGER :: ks, ke

  !  (OUT)...
 !  REAL, DIMENSION(ks:ke):: siz,siv,csz,csv

  !  (INTERNAL)...
      REAL    :: latz, latv
      INTEGER :: k

      DO k=ks,ke
        latz = latB +dlat*FLOAT(k-1) ! Lat(deg.) at the CENTER of CELL (z cal point)
        latv = latz +0.5*dlat        ! Lat(deg.) at the TOP of CELL    (v cal point)

        siz(k) = SIN(latz*rad)       ! sin for z cal point (use only for Coriolis term in un cal)
        csz(k) = COS(latz*rad)       ! cos for z cal point

        siv(k) = SIN(latv*rad)       ! sin for v cal point (use only for Coriolis term in vn cal)
        csv(k) = COS(latv*rad)       ! cos for v cal point
      END DO

      END SUBROUTINE

!---------------------------------------------------------------------
      SUBROUTINE OKADA3D_REC( js, je, ks, ke,     &
                        dx, dy, csz,              &
                        lonL, latB,               &
                        lonR, latR, dR,           &
                        L, W, D0,                 &
                        strike, dip,  rake,       &
                        disx,   disy, disz  )
!---------------------------------------------------------------------
!        3D Half-Space Static Surface Displacement Solution
!                       for Rectanglar Fault
!---------------------------------------------------------------------
!  This subroutine solves the analytical solution of Okada (1985)
!  for 3D half-space static surface displacement due to rectanglar
!  fault based on
!
!    Okada, Y. 1985. Surface deformation due to shear and
!                    tensile faults in a half space.
!                    Bulletin of the Seismological Society
!                    of America,75(4) 1135-1154.
!
!   Y.Yong     2006  ORE, University of Hawaii Manoa
!   A.Sanchez  2007  ORE, University of Hawaii Manoa
!   Y.Yamazaki 2007  ORE, University of Hawaii Manoa
!---------------------------------------------------------------------
!      USE ALL_INPUTS
      IMPLICIT NONE

!  (IN)...
      REAL(dp) :: D0
      REAL(dp) :: L, W
      REAL(dp) :: lonR, latR, dR
      REAL(dp) :: strike, dip, rake

      REAL, DIMENSION(ks:ke) :: csz
      REAL :: dx, dy
      REAL :: lonL, latB
      INTEGER :: js, je, ks, ke

!  (OUT)...
      REAL(dp), DIMENSION(js:je, ks:ke) :: disx, disy, disz

!  (INTERNAL)...
      REAL(dp) :: sins, coss
      REAL(dp) :: sind, cosd
      REAL(dp) :: sinr, cosr

      REAL(dp) :: xj, yk, zl
      REAL(dp) :: D0s, D0d
      REAL(dp) :: pk, qk
      REAL(dp) :: xjS, xjE, pkS, pkE

      REAL(dp) :: fsx1, fsy1, fsz1
      REAL(dp) :: fsx2, fsy2, fsz2
      REAL(dp) :: fsx3, fsy3, fsz3
      REAL(dp) :: fsx4, fsy4, fsz4

      REAL(dp) :: fdx1, fdy1, fdz1
      REAL(dp) :: fdx2, fdy2, fdz2
      REAL(dp) :: fdx3, fdy3, fdz3
      REAL(dp) :: fdx4, fdy4, fdz4

      REAL(dp) :: dsx, dsy, dsz
      REAL(dp) :: ddx, ddy, ddz

      REAL(dp), DIMENSION(js:je) :: x_a
      REAL(dp), DIMENSION(ks:ke) :: y_a

      INTEGER :: j, k

!      PRINT *, ' Reference Point'
!      PRINT *, '             ',latR,'(deg N)'
!      PRINT *, '             ',lonR,'(deg E)'
!      PRINT *, ' Fault Dimension'
!      PRINT *, '   L        =', L/1000.,  '(km)'
!      PRINT *, '   W        =', W/1000.,   '(km)'
!      PRINT *, ' '
!      PRINT *, '  depth     =',dR/1000.,'(km)'
!      PRINT *, ' '
!      PRINT *, '  slip      =', D0,       '(m)'
!      PRINT *, ' '
!      PRINT *, '  strike    =', strike,'(deg)'
!      PRINT *, '  dip       =', dip,   '(deg)'
!      PRINT *, '  rake      =', rake,  '(deg)'


! sine & cosine of DIP angle
      sind=SIN(dip)
      cosd=COS(dip)
      IF(ABS(cosd) .LT. 1.0d-4) THEN
        cosd=0.0d0
        if (sind.GT.0.) sind= 1.0d0
        if (sind.LT.0.) sind=-1.0d0
      END IF

! sine & cosine of RAKE angle
      sinr=SIN(rake)
      cosr=COS(rake)
      IF (ABS(cosr) .LT. 1.0d-4) THEN
        cosr=0.0d0
        if (sinr.GT.0.) sinr= 1.0d0
        if (sinr.LT.0.) sinr=-1.0d0
      END IF

! sine & cosine of STRIKE angle
      sins=SIN(strike)
      coss=COS(strike)
      IF (ABS(coss) .LT. 1.0d-4) THEN
        coss=0.0d0
        if (sins.GT.0.) sins= 1.0d0
        if (sins.LT.0.) sins=-1.0d0
      END IF

! strike and dip components of dislocation (slip)
      D0s = D0*cosr                      !strike-component
      D0d = D0*sinr                      !dip-component

      DO k = ks, ke
        DO j = js, je

! set reference point (lonR,latR) to (0,0) to calculate distances of
! all grid points relative to reference point
          x_a(j) = (float(j)-1)*dx*COS(latR*RAD)-R0*(lonR-lonL)*RAD*COS(latR*RAD)        ! new 0805
                                                                                         ! match exactly with Alex matlab code
                                                                                         ! but need more TEST wirh Dr. Kowalik's
                                                                                         ! csz(k)
!      x_a(j) = (float(j)-1)*dx*csz(k)*COS(latR*RAD)  -R0*(lonR-lonL)*RAD*COS(latR*RAD)  ! Alex version
!      x_a(j) = (float(j)-1)*dx*csz(k)                -R0*(lonR-lonL)*RAD*COS(latB*RAD)  ! old COMCOT

          y_a(k) = (float(k)-1)*dy                    -R0*(latR-latB)*RAD

! x-axis in Okada 1985
! (strike direction axis)
          xj = x_a(j)*sins +y_a(k)*coss
!        xj = x_a(j)

! y-axis in Okada 1985
! (axis normal to strike direction)
          yk = -x_a(j)*coss +y_a(k)*sins
!       yk = y_a(k)

! z-axis in Okada 1985
! (vertical axis)  
          zl = 0.0     ! at free surface (seabed)

! p-axis in Okada 1985
! (dip direction axis)
          pk = yk*COSD + dR*SIND

! q-axis in Okada 1985
! (axis normal to dip direction)
          qk = yk*SIND - dR*COSD

          xjS = xj     ! = x
          xjE = xj -L  ! = x -L
          pkS = pk     ! = p
          pkE = pk +W  ! = p +W

! --------------------------------------------------------------------
!  cal. of STRIKE-slip component DISLOCATION, dsx, dsy, dsz
! --------------------------------------------------------------------
          CALL STRIKEDIS(qk,xjS,pkE,fsx1,fsy1,fsz1,sind,cosd) ! f( x ,p+W)
          CALL STRIKEDIS(qk,xjS,pkS,fsx2,fsy2,fsz2,sind,cosd) ! f( x , p )
          CALL STRIKEDIS(qk,xjE,pkE,fsx3,fsy3,fsz3,sind,cosd) ! f(x-L,p+W)
          CALL STRIKEDIS(qk,xjE,pkS,fsx4,fsy4,fsz4,sind,cosd) ! f(x-L, p )

! f(x,p+W) - f(x,p) - f(x-L,p+W) + f(x-L,p)
          dsx=D0s*(fsx1-fsx2-fsx3+fsx4)
          dsy=D0s*(fsy1-fsy2-fsy3+fsy4)
          dsz=D0s*(fsz1-fsz2-fsz3+fsz4)

! --------------------------------------------------------------------
!  cal. of DIP-slip component DISLOCATION, ddx, ddy, ddz
! --------------------------------------------------------------------
          CALL DIPDIS(qk,xjS,pkE,fdx1,fdy1,fdz1,sind,cosd) ! f( x ,p+W)
          CALL DIPDIS(qk,xjS,pkS,fdx2,fdy2,fdz2,sind,cosd) ! f( x , p )
          CALL DIPDIS(qk,xjE,pkE,fdx3,fdy3,fdz3,sind,cosd) ! f(x-L,p+W)
          CALL DIPDIS(qk,xjE,pkS,fdx4,fdy4,fdz4,sind,cosd) ! f(x-L, p )

! f(x,p+W) - f(x,p) - f(x-L,p+W) + f(x-L,p)
          ddx=D0d*(fdx1-fdx2-fdx3+fdx4)
          ddy=D0d*(fdy1-fdy2-fdy3+fdy4)
          ddz=D0d*(fdz1-fdz2-fdz3+fdz4)

! --------------------------------------------------------------------
!  TOTAL DISLOCATION, hdx, hdy, vdz
! --------------------------------------------------------------------

          disx(j,k) = dsx+ddx
          disy(j,k) = dsy+ddy
          disz(j,k) = dsz+ddz
        END DO
      END DO

      END SUBROUTINE

!---------------------------------------------------------------------
      SUBROUTINE DIPDIS (qj,xix,etap,fdx,fdy,fdz,sind,cosd)
!---------------------------------------------------------------------
!                  Dip-slip Displacement solver
!                       for Rectanglar Fault
!---------------------------------------------------------------------
!
!  This prgram solves the dip-slip component of Okada analytical
!  solution (1985) based on
!
!    Okada, Y. 1985. Surface deformation due to shear and
!                    tensile faults in a half space.
!                    Bulletin of the Seismological Society
!                    of America,75(4) 1135-1154.
!
!   Y.Yong     2006  ORE, University of Hawaii Manoa
!   Y.Yamazaki 2007  ORE, University of Hawaii Manoa
!---------------------------------------------------------------------
!      USE ALL_INPUTS
      IMPLICIT NONE

      REAL(dp) :: sind, cosd
      REAL(dp) :: qj, xix, etap, fdx, fdy, fdz
      REAL(dp) :: I1, I2, I3, I4, I5
      REAL(dp) :: ybar, dbar
      REAL(dp) :: Xa, Ra
      REAL(dp) :: Aa, Ba

      ybar = etap*cosd + qj*sind
      dbar = etap*sind - qj*cosd

      Ra = SQRT(xix**2 + etap**2 + qj**2)
      Xa = SQRT(xix**2 + qj**2)

      Aa = nu/(lambda+nu)
      Ba = ATAN(xix*etap/(qj*Ra))

      IF (qj .EQ. 0.) Ba = 0.
!      IF (Ra+etap.EQ.0.) Ra = -etap
      IF (cosd .EQ. 0.) THEN
        I1 = -Aa/2*(xix*qj/((Ra+dbar)**2))
        I3 =  Aa/2*(etap/(Ra+dbar) + (ybar*qj)/((Ra+dbar)**2) - LOG(Ra+etap))
        I4 = -Aa*qj/(Ra+dbar)
        I5 = -Aa*xix*sind/(Ra+dbar)
      ELSE
!       IF (Ra+etap.eq.0.) then
!         I4 = Aa/cosd*(log(Ra+dbar)+sind*log(Ra-etap))
!         I5 = 2.*Aa/cosd*atan((etap*(Xa+qj*cosd)+Xa*(Ra+Xa)*sind)/(xix*(Ra+Xa)*cosd))
!       ELSE
          I4 = Aa/cosd*(LOG(Ra+dbar) - sind*LOG(Ra+etap))
          I5 = 2.*Aa/cosd*ATAN((etap*(Xa+qj*cosd)+Xa*(Ra+Xa)*sind)/(xix*(Ra+Xa)*cosd))
          I1 = Aa*((-1/cosd)*(xix/(Ra+dbar))) - sind/cosd*I5
          I3 = Aa*((1/cosd)*(ybar/(Ra+dbar)) - LOG(Ra+etap))+sind/cosd*I4
          I2 = Aa*(-LOG(Ra+etap)) - I3
!       ENDIF
      ENDIF
      IF (xix .EQ. 0.) I5 = 0.

      fdx = -1/2./pi*( qj/Ra - I3*sind*cosd )                           ! udx/U2

      fdy = -1/2./pi*( ybar*qj/(Ra*(Ra+xix)) + cosd*Ba - I1*sind*cosd ) ! udx/U2

      fdz = -1/2./pi*( dbar*qj/(Ra*(Ra+xix)) + sind*Ba - I5*sind*cosd ) ! udx/U2

      RETURN
      END SUBROUTINE


!---------------------------------------------------------------------
SUBROUTINE STRIKEDIS(qj,xix,etap,fsx,fsy,fsz,sind,cosd)
!---------------------------------------------------------------------
!                  Strike-slip Displacement solver
!                       for Rectanglar Fault
!---------------------------------------------------------------------
!
!  This prgram solves the strike-slip component of Okada analytical
!  solution (1985) based on
!
!    Okada, Y. 1985. Surface deformation due to shear and
!                    tensile faults in a half space.
!                    Bulletin of the Seismological Society
!                    of America,75(4) 1135-1154.
!
!   Y.Yong     2006  ORE, University of Hawaii Manoa
!   Y.Yamazaki 2007  ORE, University of Hawaii Manoa
!---------------------------------------------------------------------
!      USE ALL_INPUTS
      IMPLICIT NONE

      REAL(dp) :: sind,cosd
      REAL(dp) :: qj, xix, etap, fsx, fsy, fsz
      REAL(dp) :: I1, I2, I3, I4, I5
      REAL(dp) :: ybar, dbar
      REAL(dp) :: Xa, Ra
      REAL(dp) :: Aa, Ba


      ybar = etap*cosd + qj*sind
      dbar = etap*sind - qj*cosd

      Ra = SQRT(xix**2 + etap**2 + qj**2)
      Xa = SQRT(xix**2 + qj**2)

      Aa = nu/(lambda+nu)
      Ba = ATAN(xix*etap/(qj*Ra))

      IF (qj .EQ. 0.) Ba=0
!      IF (Ra+etap.EQ.0.) Ra = -etap
      IF (cosd .EQ. 0.) THEN
        I1 = -Aa/2*(xix*qj/((Ra+dbar)**2))
        I3 =  Aa/2*(etap/(Ra+dbar)+(ybar*qj)/((Ra+dbar)**2) - LOG(Ra+etap))
        I4 = -Aa*qj/(Ra+dbar)
        I5 = -Aa*xix*sind/(Ra+dbar)
      ELSE
!         IF (Ra+etap.EQ.0.) THEN
!            I4 = Aa/cosd*(log(Ra+dbar)+sind*log(Ra-etap))
!            I5 = 2.*Aa/cosd*atan((etap*(Xa+qj*cosd)+Xa*(Ra+Xa)*sind)/(xix*(Ra+Xa)*cosd))
!         ELSE
        I4 = Aa/cosd*(LOG(Ra+dbar) - sind*LOG(Ra+etap))
        I5 = 2.*Aa/cosd*ATAN((etap*(Xa+qj*cosd)+Xa*(Ra+Xa)*sind)/(xix*(Ra+Xa)*cosd))
        I1 = Aa*((-1/cosd)*(xix/(Ra+dbar))) - sind/cosd*I5
        I3 = Aa*((1/cosd)*(ybar/(Ra+dbar)) - LOG(Ra+etap))+sind/cosd*I4
        I2 = Aa*(-LOG(Ra+etap)) - I3

!         ENDIF
      ENDIF
      IF (xix .EQ. 0.) I5 = 0.

!      IF (Ra+etap.EQ.0.) THEN
!        fsx = -1./2./pi*I1*sind
!      ELSE
         fsx = -1./2./pi*( xix*qj/(Ra*(Ra+etap)) + Ba + I1*sind)                ! usx/U1
         fsy = -1./2./pi*(ybar*qj/(Ra*(Ra+etap)) + qj*cosd/(Ra+etap) + I2*sind) ! usy/U1
         fsz = -1./2./pi*(dbar*qj/(Ra*(Ra+etap)) + qj*sind/(Ra+etap) + I4*sind) ! usz/U1
!      ENDIF
     
      RETURN
      END SUBROUTINE

 end program SURFACE_OKADA
